@@ -1,4 +1,6 @@
 /*
+ * @(#) socket.c  RCS: $Revision: 1.6 $ $Date: 95/03/02 12:54:08 $
+ *
  * Socket operations
  *
  * getLocalAddr - no error reporting
@@ -6,7 +8,7 @@
  * openClient - reports error
  * openServer - reports error
  */
-#ifdef _POSIX_SOURCE
+#if defined(_POSIX_SOURCE)
 #undef _POSIX_SOURCE	/* see comment below */
 #endif
 #include <sys/types.h>	/* pid_t */
@@ -15,7 +17,7 @@
  */
 #include <errno.h>	/* EINTR ENOTSOCK */
 /*
- * These symbols are defined in <sys/types.h> but not #ifdef _POSIX_SOURCE
+ * These symbols are defined in <sys/types.h> but not if _POSIX_SOURCE
  *
  * Some machines can cause them to be defined by:
  * DEC/OSF1  - #define _OSF_SOURCE
@@ -28,7 +30,7 @@ typedef unsigned short	u_short;	/* <sys/socket.h> <netinet/tcp.h> */
 typedef unsigned long  	u_long;		/* <netinet/tcp.h> */
 typedef unsigned int	u_int;		/* <sys/socket.h> and DEC OSF/1 */
 #endif
-#define _POSIX_SOURCE
+/* #define _POSIX_SOURCE /* This isn't posix source */
 #include <sys/socket.h>	/* struct sockaddr */
 			/* connect accept listen bind socket */
 			/* getpeername getsockname */
@@ -47,6 +49,14 @@ typedef unsigned int	u_int;		/* <sys/socket.h> and DEC OSF/1 */
 #include "socket.h"
 #include "deslogin.h"
 #include "posignal.h"
+#if defined(TERM_LINK)	/* { */
+/*
+ * When using a dialup line to a non-slip capable terminal server, there
+ * is a package which allows you to multiplex the serial line.  See
+ * sunsite.unc.edu:/pub/Linux/apps/comm/term/term/term117.tar.gz for details.
+ */
+#include <client.h>
+#endif			/* } */
 
 /*
  * Return a non-zero socket type of the specifed fd if it is a socket
@@ -62,7 +72,7 @@ int socktype(fd)
    int size = sizeof sotype;
    int res;
 
-   res = getsockopt(fd, SOL_SOCKET, SO_TYPE, &sotype, &size);
+   res = getsockopt(fd, SOL_SOCKET, SO_TYPE, (void *) &sotype, &size);
    if (res >= 0) {
       res = sotype;
    } else if (errno == ENOTSOCK) {
@@ -97,7 +107,7 @@ int tcpDelay(sock, flag)
    }
    tcplevel = pent->p_proto;		/* protocol number for tcp */
 
-   res = getsockopt(sock, tcplevel, TCP_NODELAY, &oldflag, &oldlen);
+   res = getsockopt(sock, tcplevel, TCP_NODELAY, (void *) &oldflag, &oldlen);
    if (res == 0) {
       oldflag = !oldflag;		/* 4 for TCP_NODELAY on, 0 for OFF */
    } else {
@@ -107,14 +117,14 @@ int tcpDelay(sock, flag)
 	 return -2;
       }
    }
-   res = setsockopt(sock, tcplevel, TCP_NODELAY, &flag, sizeof flag);
+   res = setsockopt(sock, tcplevel, TCP_NODELAY, (void *) &flag, sizeof flag);
    if (res != 0) {
       return -3;
    }
    /*
     * To detect new state when in debugger
     */
-   res = getsockopt(sock, tcplevel, TCP_NODELAY, &newflag, &newlen);
+   res = getsockopt(sock, tcplevel, TCP_NODELAY, (void *) &newflag, &newlen);
    return oldflag;
 }
 
@@ -269,7 +279,7 @@ int getServicePort(name)
    
    sent = getservbyname(name, (char *) 0);
    if (sent != (struct servent *) 0) {
-      res = sent->s_port;
+      res = ntohs(sent->s_port);
    }
    return res;
 }
@@ -391,6 +401,7 @@ int openClient(hostName, port)
    int port;
 {
    int sock, res;
+#if !defined(TERM_LINK) /* { */
    struct sockaddr addr;
    int addrLen;
 
@@ -421,5 +432,24 @@ int openClient(hostName, port)
       log("%s: tcpDelay returned (%d) --%s\n", progName, res, ERRMSG);
       /* OK to continue */
    }
+#else /* } { TERMLINK */
+   sock = connect_server(0);
+   if (sock < 0) {
+      log("%s: connect to term server failed\n", progName);
+      return -1;
+   }
+   res = send_command(sock, C_PORT, 0, "%s:%u", hostName, port);
+   if (res < 0) {
+      log("%s: send_command(%u, C_PORT, 0 \"%s:%u\") failed--%s\n", 
+	 progName, sock, hostName, port, command_result);
+      return -1;
+   }
+   res = send_command(sock, C_DUMB, 1, 0);
+   if (res < 0) {
+      log("%s: send_command(%u, C_DUMB) failed--%s\n", 
+	 progName, sock, command_result);
+      return -1;
+   }
+#endif /* } TERMLINK */
    return sock;
 }
